@@ -1,8 +1,7 @@
 package CGI::Application::Plugin::Authentication::Driver::Filter::sha1;
-
+$CGI::Application::Plugin::Authentication::Driver::Filter::sha1::VERSION = '0.22';
 use strict;
 use warnings;
-our $VERSION = '0.20';
 
 use UNIVERSAL::require;
 
@@ -25,7 +24,7 @@ sub check {
 
 sub filter {
     my $class = shift;
-    my $param = lc shift || 'hex';
+    my $param = lc (shift || 'hex');
     my $plain = shift;
 
     Digest::SHA->require || die "Digest::SHA is required to check SHA1 passwords";
@@ -47,10 +46,6 @@ __END__
 
 CGI::Application::Plugin::Authentication::Driver::Filter::sha1 - SHA1 Password filter
 
-=head1 VERSION
-
-This document describes CGI::Application::Plugin::Authentication::Driver::Filter::sha1 version 0.20
-
 =head1 METHODS
 
 
